@@ -1,9 +1,10 @@
 package File::NCopy;
-use 5.004; # just because I think you should upgrade :)
+require 5.004; # just because I think you should upgrade :)
 
 =head1 NAME
 
-File::NCopy - Almost abandoned module. Copy file, file. Copy file[s] | dir[s], dir
+B<File::NCopy> - Copy file, file
+              Copy file[s] | dir[s], dir
 
 =head1 SYNOPSIS
 
@@ -36,7 +37,6 @@ File::NCopy - Almost abandoned module. Copy file, file. Copy file[s] | dir[s], d
             'recursive'      => 0,
             'preserve'       => 0,
             'follow_links'   => 0,
-            'force_write'   => 0,
             'set_permission' => \&File::NCopy::u_chmod,
             'file_check'     => \&File::NCopy::f_check,
             'set_times'      => \&File::NCopy::s_times,
@@ -140,10 +140,6 @@ link to /usr/src/i386/sys/ rather than /usr/src/sys/ since if the link
 /usr/src/sys/ is removed then we lost the link even though the directory
 we originally intended to link to still exists.
 
-=item B<force_write>
-
-Force the writing of a file even if the permissions are read only on it.
-
 =back
 
 =head1 EXAMPLE
@@ -158,10 +154,6 @@ follow circular or dead links.  This is really a feature though the
 result may not quite resemble the source dir, the overall content will
 be the same. :)
 
-From Ken Healy (Version 0.34)
-
-On Win32, The use of backslash for paths is required.
-
 =head1 AUTHOR
 
 Gabor Egressy B<gabor@vmunix.com>
@@ -173,21 +165,17 @@ modify it under the same terms as Perl itself.
 Some ideas gleaned from File::Copy by Aaron Sherman & Charles Bailey,
 but the code was written from scratch.
 
-Patch at versions 0.33, and 0.34 added by MZSANFORD.
-
-0.34_01 - Alexandr Ciornii (alexchorny AT gmail.com)
-
 =cut
 
-use Cwd ();
-use File::Spec;
+use POSIX ();
 use strict;
-use vars qw(@EXPORT_OK @ISA $VERSION);
+use vars qw(@EXPORT_OK @ISA $VERSION $debug);
+# $debug will disappear in future versions, don't rely on it
 @ISA = qw(Exporter);
 # we export nothing by default :)
 @EXPORT_OK = qw(copy cp);
 
-$VERSION = '0.34_01';
+$VERSION = '0.30';
 
 # this works on Unix
 sub u_chmod($$)
@@ -210,13 +198,7 @@ sub f_check($$)
         or return 0;
     # try and get an exclusive lock on the file to copy to
     flock $file_to,6
-        or do {
-            flock $file_from,8;
-            return 0;
-        };
-    flock $file_from,8;
-    flock $file_to,8;
-
+        or return 0;
     1;
 }
 
@@ -244,7 +226,7 @@ sub s_times($$)
     utime $atime,$mtime,$file_to
         unless ref $file_to eq 'GLOB' || ref $file_to eq 'FileHandle';
 
-    # this may only work for men in white hats; on Unix
+    # this may only work for men in white hats
     chown $uid,$gid,$file_to
         unless ref $file_to eq 'GLOB' || ref $file_to eq 'FileHandle';
     1;
@@ -256,16 +238,11 @@ sub _docopy_file_file($$$)
     my $this = shift;
     my ($file_from,$file_to) = @_;
     local (*FILE_FROM,*FILE_TO);
-    my ($was_handle);
 
     # did we get a file handle ?
     unless(ref $file_from eq 'GLOB' || ref $file_from eq 'FileHandle') {
         open FILE_FROM,"<$file_from"
-            or do {
-                print "*** Couldn\'t open from file <$!> ==> $file_from\n"
-                    if $this->{'_debug'};
-                return 0;
-            };
+            or return 0;
     }
     else {
         *FILE_FROM = *$file_from;
@@ -279,7 +256,6 @@ sub _docopy_file_file($$$)
     }
     else {
         *FILE_TO = *$file_to;
-        $was_handle = 1;
     }
 
     unless(-t FILE_FROM || -t FILE_TO) {
@@ -288,30 +264,20 @@ sub _docopy_file_file($$$)
     }
 
 NO_FILE:
-    # files aren't the same; now open for writing unless we got a
-    # filehandle
-    if(! $was_handle && ! $this->{test}) {
-        open FILE_TO,">$file_to"
-            or chmod 0644, "$file_to"
-                if $this->{'force_write'};
-        open FILE_TO,">$file_to"
-            or do {
-                print "*** Couldn\'t open to file <$!> ==> $file_to\n"
-                    if $this->{'_debug'};
-                return 0;
-            };
-    }
+    # files aren't the same; now open for writing
+    open FILE_TO,">$file_to"
+        or return 0;
 
     # and now for the braindead OS's
-    binmode FILE_FROM unless ($this->{test});
-    binmode FILE_TO   unless ($this->{test});
+    binmode FILE_FROM;
+    binmode FILE_TO;
 
     my $buf = '';
     my ($len,$write_n);
     # read file and write to new file, recover from write errors and
     # read errors; we accept however much we read and try to write it
     # 8K is a nice buffer size for most file systems
-    while(! $this->{test} && 1) {
+    while(1) {
         $len = sysread(FILE_FROM,$buf,8192);
         return 0
             unless defined $len;
@@ -326,21 +292,17 @@ NO_FILE:
     }
 
     $this->{'set_permission'}->($file_from,$file_to);
+    $this->{'set_times'}->($file_from,$file_to)
+        if $this->{'preserve'};
 
     # we only close files we opened
-    unless ($this->{test}) {
     close FILE_FROM
         unless ref $file_from eq 'GLOB' || ref $file_from eq 'FileHandle';
     close FILE_TO
         unless ref $file_to eq 'GLOB' || ref $file_to eq 'FileHandle';
-    }
-
-    # this was moved from above the unless statement per Ken Healy in version 0.34
-    $this->{'set_times'}->($file_from,$file_to)
-        if $this->{'preserve'};
 
     print "$file_from ==> $file_to\n"
-        if $this->{'_debug'};
+        if $debug;
 
     1;
 }
@@ -349,10 +311,10 @@ sub get_path($)
 {
     my $dir = shift;
 
-    my $save_dir = Cwd::cwd;
+    my $save_dir = POSIX::getcwd;
     chdir $dir
         or return undef;
-    $dir = Cwd::cwd;
+    $dir = POSIX::getcwd;
     chdir $save_dir;
 
     $dir;
@@ -366,27 +328,15 @@ sub _recurse_from_dir($$$)
     my $this = shift;
     my ($from_dir,$to_dir) = @_;
     local (*DIR);
-    # MZS - v0.39 - Changed from slash to File::Spec;
-    my $dir_sep = File::Spec->catfile('a','b');
-    $dir_sep =~ s/^a(.+)b$/$1/;
-
 
     opendir DIR,$from_dir
-        or do {
-            print "*** Couldn\'t opendir <$!> ==> $from_dir\n"
-                if $this->{'_debug'};
-            return 0;
-        };
-    my @files = readdir DIR
-        or do {
-            print "*** Couldn\'t read dir <$!> ==> $from_dir\n"
-                if $this->{'_debug'};
-            return 0;
-        };
+        or return 0;
+    my @files = grep {! /^\.\.?$/} readdir DIR
+        or return 0;
     closedir DIR;
 
     my $made_dir;
-    unless(-e $to_dir && ! $this->{test}) {
+    unless(-e $to_dir) {
         mkdir $to_dir,0777
             or return 0;
         $made_dir = 1;
@@ -404,25 +354,23 @@ sub _recurse_from_dir($$$)
     }
 
     for (@files) {
-        next
-            if /^\.\.?$/;
-        if(-f $from_dir . $dir_sep . $_) {
-            $ret = _docopy_file_file $this, $from_dir . $dir_sep . $_ ,
-                    $to_dir . $dir_sep . $_;
+        if(-f "$from_dir/$_") {
+            $ret = _docopy_file_file $this, $from_dir . '/' . $_ ,
+                    $to_dir . '/' . $_;
         }
-        elsif(-d "$from_dir$dir_sep$_") {
-            if($this->{'follow_links'} && -l "$from_dir$dir_sep$_") {
-                $link = get_path "$from_dir$dir_sep$_";
+        elsif(-d "$from_dir/$_") {
+            if($this->{'follow_links'} && -l "$from_dir/$_") {
+                $link = get_path "$from_dir/$_";
             }
-            if(! -l "$from_dir$dir_sep$_" || $this->{'follow_links'}
+            if(! -l "$from_dir/$_" || $this->{'follow_links'}
                     && defined $link
                     && ! exists $this->{'_links'}->{$link}) {
                 $ret = _recurse_from_dir
-                        $this,$from_dir . $dir_sep . $_ ,$to_dir . $dir_sep . $_;
+                        $this,$from_dir . '/' . $_ ,$to_dir . '/' . $_;
             }
             else {
-                if(defined($link = get_path "$from_dir$dir_sep$_")) {
-                    $ret = symlink $link, "$to_dir$dir_sep$_";
+                if(defined($link = get_path "$from_dir/$_")) {
+                    $ret = symlink $link, "$to_dir/$_";
                 }
             }
         }
@@ -449,13 +397,10 @@ sub _docopy_dir_dir($$$)
     my $this = shift;
     my ($dir_from,$dir_to) = @_;
     my ($from_name);
-    # MZS - v0.39 - Changed from slash to File::Spec;
-    my $dir_sep = File::Spec->catfile('a','b');
-    $dir_sep =~ s/^a(.+)b$/$1/;
 
-    $dir_from =~ s/$dir_sep$//; # remove trailing slash, if any
-    if($dir_from =~ tr/$dir_sep//) {
-        $from_name = substr $dir_from,rindex($dir_from,$dir_sep) + 1;
+    $dir_from =~ s/\/$//; # remove trailing slash, if any
+    if($dir_from =~ tr/\///) {
+        $from_name = substr $dir_from,rindex($dir_from,'/') + 1;
     }
     else {
         $from_name = $dir_from;
@@ -464,8 +409,8 @@ sub _docopy_dir_dir($$$)
         }
     }
 
-    unless($dir_to =~ /$dir_sep$/) {
-        $dir_to .= $dir_sep;
+    unless($dir_to =~ /\/$/) {
+        $dir_to .= '/';
     }
     $dir_to .= $from_name;
 
@@ -479,20 +424,17 @@ sub _docopy_file_dir($$$)
     my $this = shift;
     my ($file,$dir) = @_;
     my $file_to;
-    # MZS - v0.39 - Changed from slash to File::Spec;
-    my $dir_sep = File::Spec->catfile('a','b');
-    $dir_sep =~ s/^a(.+)b$/$1/;
 
-    if($file =~ tr/$dir_sep//) {
-        $file_to = substr $file,rindex($file,$dir_sep) + 1;
+    if($file =~ tr/\///) {
+        $file_to = substr $file,rindex($file,'/') + 1;
     }
     else {
         $file_to = $file;
     }
-    
-    $dir =~ s/$dir_sep$//; # remove trailing slash 
 
-    _docopy_file_file $this, $file,$dir.$dir_sep.$file_to;
+    $dir =~ s/\/$//; # remove trailing slash
+
+    _docopy_file_file $this, $file,$dir.'/'.$file_to;
 }
 
 # this just redirects calls, like copy ;)
@@ -504,20 +446,12 @@ sub _docopy_files_dir($$@)
 
     for (@_) {
         if(-d $_ && $this->{'recursive'}) {
-            if ($this->{test}) {
-                push @$copies, $_;
-            } else {
             _docopy_dir_dir $this, $_, $dir
                 and push @$copies, $_;
-            }
         }
         elsif(-f $_) {
-            if ($this->{test}) {
-                push @$copies, $_;
-            } else {
             _docopy_file_dir $this, $_, $dir
                 and push @$copies, $_;
-            }
         }
     }
     1;
@@ -552,7 +486,7 @@ sub copy(@)
     }
     else {
         # no, so let's make one
-        $this = new File::NCopy;
+        $this = new;
         if(ref $_[0] eq 'SCALAR') {
             my $rec = shift;
             $this->recursive($$rec);
@@ -562,22 +496,14 @@ sub copy(@)
     my @copies;
     my @args = expand @_;
 
-    print "passed args ==> ".join(',',map {"'$_'"} @args)."\n"
-        if $this->{'_debug'};
-
     # one or more files/directories to a directory
     if(@args >= 2 && -d $args[$#args]) {
-        print "Copy to dir started.\n" if ($this->{'_debug'});
         _docopy_files_dir $this, \@copies, @args;
     }
     # file to file
     elsif(@args == 2 && -f $args[0]) {
-        if ($this->{test}) {
-                push @copies, $args[0];
-        } else {
         _docopy_file_file $this, $args[0],$args[1]
             and push @copies, $args[0];
-        }
     }
 
     @copies;
@@ -593,12 +519,9 @@ sub new(@)
     my $this = shift;
     
     my $conf = {
-        'test'           => 0,
         'recursive'      => 0,
         'preserve'       => 0,
         'follow_links'   => 0,
-        'force_write'    => 0,
-        '_debug'         => 0,
         'set_permission' => \&File::NCopy::u_chmod,
         'file_check'     => \&File::NCopy::f_check,
         'set_times'      => \&File::NCopy::s_times,
@@ -615,18 +538,12 @@ sub new(@)
     }
 
     if(ref $ref eq 'HASH') {
-        $conf->{'test'} = abs int $ref->{'test'}
-            if defined $ref->{'test'};
         $conf->{'recursive'} = abs int $ref->{'recursive'}
             if defined $ref->{'recursive'};
         $conf->{'preserve'} = abs int $ref->{'preserve'}
             if defined $ref->{'preserve'};
         $conf->{'follow_links'} = abs int $ref->{'follow_links'}
             if defined $ref->{'follow_links'};
-        $conf->{'force_write'} = abs int $ref->{'force_write'}
-            if defined $ref->{'force_write'};
-        $conf->{'_debug'} = abs int $ref->{'_debug'}
-            if defined $ref->{'_debug'};
         $conf->{'set_permission'} = $ref->{'set_permission'}
             if defined $ref->{'set_permission'}
                 && ref $ref->{'set_permission'} eq 'CODE';
@@ -680,17 +597,4 @@ sub follow_links($;$)
        : $this->{'follow_links'};
 }
 
-sub force_write($;$)
-{
-    return
-        if @_ < 1;
-    my $this = shift;
-
-    return
-        unless ref $this eq 'File::NCopy';
-
-    @_ ? $this->{'force_write'} = abs int shift
-       : $this->{'force_write'};
-}
-
 1;
